#ifndef MPU_LMO_H
#define MPU_LMO_H

#include "ptypes.h"

extern UV LMO_prime_count(UV n);

extern UV legendre_phi(UV n, UV a);

#endif
